@@ -9,6 +9,21 @@ Item_Data = {
 		AllSkills = 1,
 	},
 
+	-- Lava Amulet
+	[316] = {
+		MaxFireResist = 5,
+	},
+
+	-- Chilly Amulet
+	[355] = {
+		MaxColdResist = 5,
+	},
+
+	-- Hangman's Noose
+	[422] = {
+		Cursed = true,
+	},
+
 -- Rings
 
 	-- Attack Power Ring
@@ -19,6 +34,7 @@ Item_Data = {
 	-- Elusive One
 	[273] = {
 		Initiative = 10,
+		Delete = false,
 	},
 
 	-- Greater Ring of Pain
@@ -33,16 +49,46 @@ Item_Data = {
 
 -- Relics
 
+	-- Greed
+	[376] = {
+		Endure = true,
+	},
+
+	-- Wisdom
+	[377] = {
+		Endure = true,
+	},
+
 	-- Suffering
 	[379] = {
-		Cursed = true,
+		Endure = true,
+	},
+
+	-- Dimensionality
+	[371] = {
+		Delete = false,
+	},
+
+	-- Flippers
+	[387] = {
+		Delete = false,
+	},
+
+	-- Mountain Climbers
+	[388] = {
+		Delete = false,
 	},
 
 -- One-Handed Weapons
 
+	-- Flamuss
+	[266] = {
+		GoldGained = 5,
+	},
+
 	-- Shining Star
 	[290] = {
-		ExperienceBonus = 5,
+		ExperienceGained = 5,
 	},
 
 	-- Bone Wand
@@ -86,4 +132,12 @@ Item_Data = {
 	[46] = {
 		BuffPriority = 1,
 	},
-}
\ No newline at end of file
+
+-- Boots
+
+	-- Dimensional Slippers
+	[263] = {
+		Delete = false,
+	},
+
+}
